.. :changelog:

History
-------

0.2.0 (2014-1-25)
++++++++++++++++++

* Forgot a requirement for Travis-CI

0.1.0 (2014-1-25)
++++++++++++++++++

* Added simple entity component system
* First release on PyPI.
